package App::CompleteUtils;

our $DATE = '2017-07-05'; # DATE
our $VERSION = '0.15'; # VERSION

use 5.010001;
use strict;
use warnings;

1;
# ABSTRACT: Collection of CLI utilities related to completion and Complete::*

__END__

=pod

=encoding UTF-8

=head1 NAME

App::CompleteUtils - Collection of CLI utilities related to completion and Complete::*

=head1 VERSION

This document describes version 0.15 of App::CompleteUtils (from Perl distribution App-CompleteUtils), released on 2017-07-05.

=head1 SYNOPSIS

This distribution provides several command-line utilities related to
(shell) completion and the L<Complete> modules family:

=over

=item * L<compwithargs>

=item * L<testcomp>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-CompleteUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-CompleteUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-CompleteUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Complete>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017, 2016, 2015, 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
